@@ -2,12 +2,11 @@
 // SPDX-FileCopyrightText: 2021 Carl Schwan <carl@carlschwan.eu>
 // SPDX-License-Identifier: GPL-3.0-only
 
-#include "account.h"
+#include "account/account.h"
 
-#include "networkcontroller.h"
-#include "notificationhandler.h"
+#include "account/notificationhandler.h"
+#include "network/networkcontroller.h"
 #include "tokodon_http_debug.h"
-#include "utils.h"
 
 #ifdef HAVE_KUNIFIEDPUSH
 #include "ecdh.h"
@@ -25,9 +24,7 @@ Account::Account(const QString &instanceUri, QNetworkAccessManager *nam, bool ig
 {
     m_preferences = new Preferences(this);
     setInstanceUri(instanceUri);
-    registerApplication(QStringLiteral("Tokodon"),
-                        QStringLiteral("https://apps.kde.org/tokodon"),
-                        admin ? QStringLiteral("admin:read admin:write") : QStringLiteral(""));
+    m_requestingAdmin = admin;
 }
 
 Account::Account(AccountConfig *settings, QNetworkAccessManager *nam, QObject *parent)
@@ -71,7 +68,7 @@ void Account::post(const QUrl &url,
 
     QNetworkRequest request = makeRequest(url, authenticated);
     request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/json"));
-    for (const auto [headerKey, headerValue] : asKeyValueRange(headers)) {
+    for (const auto [headerKey, headerValue] : headers.asKeyValueRange()) {
         request.setRawHeader(headerKey, headerValue);
     }
     qCDebug(TOKODON_HTTP) << "POST" << url << "[" << post_data << "]";
@@ -134,7 +131,7 @@ QNetworkReply *Account::post(const QUrl &url, QHttpMultiPart *message, bool auth
     QNetworkReply *reply = m_qnam->post(request, message);
     reply->setParent(parent);
     handleReply(reply, reply_cb);
-	return reply;
+    return reply;
 }
 
 void Account::patch(const QUrl &url, QHttpMultiPart *multiPart, bool authenticated, QObject *parent, std::function<void(QNetworkReply *)> callback)
@@ -412,19 +409,13 @@ void Account::buildFromSettings()
     clientSecretJob->start();
 }
 
-bool Account::hasFollowRequests() const
-{
-    return m_hasFollowRequests;
-}
-
 void Account::checkForFollowRequests()
 {
     get(apiUrl(QStringLiteral("/api/v1/follow_requests")), true, this, [this](QNetworkReply *reply) {
         const auto followRequestResult = QJsonDocument::fromJson(reply->readAll());
-        const bool hasFollowRequests = followRequestResult.isArray() && !followRequestResult.array().isEmpty();
-        if (hasFollowRequests != m_hasFollowRequests) {
-            m_hasFollowRequests = hasFollowRequests;
-            Q_EMIT hasFollowRequestsChanged();
+        if (m_followRequestCount != followRequestResult.array().size()) {
+            m_followRequestCount = followRequestResult.array().size();
+            Q_EMIT followRequestCountChanged();
         }
     });
 }
@@ -526,4 +517,12 @@ QUrlQuery Account::buildNotificationFormData()
     return formdata;
 }
 
+void Account::registerTokodon(const bool authCode)
+{
+    registerApplication(QStringLiteral("Tokodon"),
+                        QStringLiteral("https://apps.kde.org/tokodon"),
+                        m_requestingAdmin ? QStringLiteral("admin:read admin:write") : QStringLiteral(""),
+                        authCode);
+}
+
 #include "moc_account.cpp"
