@@ -1,10 +1,10 @@
 // SPDX-FileCopyrightText: 2022 Carl Schwan <carl@carlschwan.eu>
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-#include "notificationhandler.h"
+#include "account/notificationhandler.h"
 
-#include "account.h"
-#include "networkcontroller.h"
+#include "account/account.h"
+#include "network/networkcontroller.h"
 
 #include <QPainter>
 
@@ -136,7 +136,7 @@ void NotificationHandler::handle(std::shared_ptr<Notification> notification, Abs
     }
 
     if (notification->post() != nullptr) {
-        knotification->setText(notification->post()->content());
+        knotification->setText(notification->post()->plainContent());
     }
     knotification->setHint(QStringLiteral("x-kde-origin-name"), account->identity()->displayName());
 
@@ -175,12 +175,10 @@ void NotificationHandler::handle(std::shared_ptr<Notification> notification, Abs
 
             QBrush brush(img.scaledToHeight(biggestDimension));
             painter.setBrush(brush);
-            painter.drawRoundedRect(imageRect, imageRect.width(),
-                                    imageRect.height());
+            painter.drawRoundedRect(imageRect, imageRect.width(), imageRect.height());
             painter.end();
 
-            knotification->setPixmap(
-                QPixmap::fromImage(std::move(roundedImage)));
+            knotification->setPixmap(QPixmap::fromImage(std::move(roundedImage)));
             knotification->sendEvent();
         });
     } else {
