@@ -47,8 +47,6 @@ public:
 
     void validateToken(bool newAccount = false) override;
 
-    bool hasFollowRequests() const override;
-
     void checkForFollowRequests() override;
 
     void registerPost(const QString &url, QNetworkReply *reply);
@@ -69,6 +67,9 @@ public:
     Q_INVOKABLE void updateNotification();
     Q_INVOKABLE void pollNotification();
 
+    Q_INVOKABLE void increaseFollowRequests();
+    Q_INVOKABLE void decreaseFollowRequests();
+
 private:
     void readNotificationFromFile(QLatin1String filename);
 
