@@ -3,11 +3,13 @@
 
 #include <QtTest/QtTest>
 
-#include "helperreply.h"
-#include "mockaccount.h"
+#include "autotests/helperreply.h"
+#include "autotests/mockaccount.h"
 #include "timeline/maintimelinemodel.h"
 #include "timeline/tagstimelinemodel.h"
 #include "timeline/threadmodel.h"
+#include "utils/texthandler.h"
+
 #include <KLocalizedString>
 
 using namespace Qt::Literals::StringLiterals;
@@ -49,11 +51,6 @@ private Q_SLOTS:
         timelineModel.setName(QStringLiteral("home"));
         QCOMPARE(timelineModel.displayName(), QStringLiteral("Home"));
 
-        auto account2 = new MockAccount();
-        AccountManager::instance().addAccount(account2, false);
-
-        QCOMPARE(timelineModel.displayName(), QStringLiteral("Home (test)"));
-
         account->clearFakeIdentity();
     }
 
@@ -145,7 +142,8 @@ private Q_SLOTS:
 
         QCOMPARE(timelineModel.data(timelineModel.index(0, 0), AbstractTimelineModel::IdRole).value<QString>(), QStringLiteral("103270115826048975"));
         QCOMPARE(timelineModel.data(timelineModel.index(0, 0), AbstractTimelineModel::MentionsRole).value<QStringList>(), QStringList{});
-        QCOMPARE(timelineModel.data(timelineModel.index(0, 0), AbstractTimelineModel::ContentRole).value<QString>(), QStringLiteral("<p>LOREM</p>"));
+        QCOMPARE(timelineModel.data(timelineModel.index(0, 0), AbstractTimelineModel::ContentRole).value<QString>(),
+                 TextHandler::fixBidirectionality(QStringLiteral("<p>LOREM</p>")));
         QCOMPARE(timelineModel.data(timelineModel.index(0, 0), AbstractTimelineModel::AuthorIdentityRole).value<Identity *>()->id(), QStringLiteral("1"));
         QCOMPARE(timelineModel.data(timelineModel.index(0, 0), AbstractTimelineModel::AuthorIdentityRole).value<Identity *>()->displayNameHtml(),
                  QStringLiteral("Eugen <img height=\"16\" align=\"middle\" width=\"16\" src=\"https://kde.org\">"));
