@@ -2,7 +2,10 @@
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include <QQuickStyle>
+
+#ifdef HAVE_WEBVIEW
 #include <QtWebView>
+#endif
 
 #ifdef Q_OS_ANDROID
 #include "utils/androidutils.h"
@@ -33,7 +36,6 @@
 #include "tokodon_debug.h"
 #include "utils/blurhashimageprovider.h"
 #include "utils/colorschemer.h"
-#include "utils/navigation.h"
 #include "utils/windowcontroller.h"
 
 #ifdef Q_OS_WINDOWS
@@ -67,7 +69,10 @@ Q_DECL_EXPORT
 int main(int argc, char *argv[])
 {
     QNetworkProxyFactory::setUseSystemConfiguration(true);
+
+#ifdef HAVE_WEBVIEW
     QtWebView::initialize();
+#endif
 
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
@@ -234,7 +239,7 @@ int main(int argc, char *argv[])
     AccountManager::instance().selectAccount(account);
 
     QUrl url = account->apiUrl(QStringLiteral("/api/v2/search"));
-    url.setQuery(QUrlQuery{{QStringLiteral("q"), QStringLiteral("myquery")}});
+    url.setQuery(QUrlQuery{{QStringLiteral("q"), QStringLiteral("myquery")}, {QStringLiteral("resolve"), QStringLiteral("true")}});
     account->registerGet(url, new TestReply(QStringLiteral("search-result.json"), account));
 
     account->registerGet(account->apiUrl(QStringLiteral("/api/v1/timelines/home")), new TestReply(QStringLiteral("statuses.json"), account));
