@@ -2,7 +2,7 @@
 // SPDX-FileCopyrightText: 2021 Carl Schwan <carlschwan@kde.org>
 // SPDX-License-Identifier: GPL-3.0-only
 
-#include "timelinemodel.h"
+#include "timeline/timelinemodel.h"
 
 using namespace Qt::Literals::StringLiterals;
 
